%global __cmake_in_source_build 1
%define oname PDAL
%define major		17
%define libname		%mklibname pdal %{major}
%define develname	%mklibname pdal -d

# We don't want to provide private PDAL extension libs (to be verified)
%define _requires_exceptions ^%{_libdir}/libpdal_plugin.*\.so.*$
%define _provides_exceptions ^%{_libdir}/libpdal_plugin.*\.so.*$

Summary:	Point Data Abstraction Library
Name:		pdal
Version:	   2.7.1
Release:	  %mkrel 1
Group:	System/Libraries
License:	BSD-3-Clause AND Apache-2.0 AND MIT AND BSL-1.0
URL:		https://www.pdal.io
Source:		https://github.com/%{oname}/%{oname}/releases/download/%{version}/%{oname}-%{version}-src.tar.xz
Patch0:		PDAL_unbundle.patch

BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	eigen3
BuildRequires:	gcc-c++
BuildRequires:	gdal-devel
BuildRequires:	geos-devel
BuildRequires:	gtest-devel
BuildRequires:	hdf5-devel
BuildRequires:	jsoncpp-devel
BuildRequires:	lib64geotiff-devel
BuildRequires:	libpq-devel
BuildRequires:	libxml2-devel
BuildRequires:	libzstd-devel
BuildRequires:  make
BuildRequires:	lib64netcdf-devel
BuildRequires:	postgresql-devel
BuildRequires:	postgresql-server
BuildRequires:	proj-devel
BuildRequires:	python3-breathe
BuildRequires:	python3-devel
BuildRequires:	python3-numpy
BuildRequires:	python3-sphinx
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	qhull-devel
BuildRequires:	sqlite-devel
BuildRequires:	zlib-devel

Requires:	bash-completion
Requires:	%{libname} = %{version}-%{release}

%description
PDAL is a BSD licensed library for translating and manipulating point cloud
data of various formats. It is a library that is analogous to the GDAL raster
library. PDAL is focused on reading, writing, and translating point cloud
data from the ever-growing constellation of data formats. While PDAL is not
explicitly limited to working with LiDAR data formats, its wide format
coverage is in that domain.

PDAL is related to Point Cloud Library (PCL) in the sense that both work with
point data, but PDAL’s niche is data translation and processing pipelines, and
PCL’s is more in the algorithmic exploitation domain. There is cross over of
both niches, however, and PDAL provides a user the ability to exploit data
using PCL’s techniques.

%package -n	%{libname}
Summary:	The shared libraries required for PDAL
Group: 		System/Libraries
Requires:   %{name} = %{version}-%{release}

%description -n	%{libname}
The pdal-libs package provides the essential shared libraries for any
PDAL client program or interface. You will need to install this package
to use PDAL

%package -n	%{develname}
Summary:	PDAL development header files and libraries
Group:      Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}

%description -n	%{develname}
The pdal-devel package contains the header files and libraries needed to
compile C or C++ applications which will directly interact with PDAL.


%prep
%autosetup -p1 -n %{oname}-%{version}-src
# Wrong perms on some source files
chmod 0644 pdal/DynamicLibrary.cpp pdal/private/DynamicLibrary.hpp

# Remove some bundled libraries
rm -rf vendor/{eigen,gtest,pdalboost}


%build
%cmake	\
	-D PDAL_LIB_INSTALL_DIR:PATH=%{_lib} \
	-D CMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
	-D CMAKE_VERBOSE_MAKEFILE=ON  \
	-D GEOTIFF_INCLUDE_DIR=%{_includedir}/libgeotiff \
	-D BUILD_PGPOINTCLOUD_TESTS:BOOL=OFF \
	-D WITH_COMPLETION=ON \
	-D WITH_LAZPERF=ON \
	-D WITH_TESTS=ON \
	-D PDAL_HAVE_LIBGEOTIFF=ON \
	-D PDAL_HAVE_LIBXML2=ON \
	-D POSTGRESQL_INCLUDE_DIR=%{_includedir}/pgsql \
	-D POSTGRESQL_LIBRARIES=%{_libdir}/libpq.so

%cmake_build

%install
%cmake_install

%check
#ctest || :

%files
%{_bindir}/pdal
%{_datadir}/bash-completion/completions/pdal

%files -n	%{libname}
%{_libdir}/libpdal_plugin_kernel_fauxplugin.so.%{major}*
%{_libdir}/libpdal_plugin_reader_pgpointcloud.so.%{major}*
%{_libdir}/libpdal_plugin_writer_pgpointcloud.so.%{major}*
%{_libdir}/libpdalcpp.so.%{major}*

%files -n	%{develname}
%{_bindir}/pdal-config
%{_includedir}/pdal/
# drop unversioned symbolic links (BZ#1841616)
%exclude %{_libdir}/libpdal_plugin_kernel_fauxplugin.so
%exclude %{_libdir}/libpdal_plugin_reader_pgpointcloud.so
%exclude %{_libdir}/libpdal_plugin_writer_pgpointcloud.so
%{_libdir}/libpdalcpp.so
%{_libdir}/cmake/PDAL/
%{_libdir}/pkgconfig/*.pc


%changelog
* Sun Mar 31 2024 pp - 2.7.1-1pclos2024
- new version

* Tue Mar 05 2024 pp - 2.6.3-2pclos2024
- rebuild against new proj

* Fri Feb 09 2024 pp - 2.6.3-1pclos2024
- new version

* Fri Jan 12 2024 pp - 2.6.2-1pclos2024
- new version

* Wed Dec 27 2023 pp - 2.5.6-2pclos2024
- rebuild against new gdal

* Thu Aug 31 2023 pp - 2.5.6-1pclos2023
- new version

* Tue Jun 27 2023 pp - 2.5.5-1pclos2023
- imported package
